@@ -91,8 +91,7 @@ cc	DIMENSION IQI(25),IPI(25),SAIC(25)
 c
       DIMENSION CYY1(LAGH01)
       DIMENSION IQI1(NEWL1),IPI1(NEWL1)
-cxx      DIMENSION A1(IPI1(1)),B1(IQI1(1))
-      DIMENSION A1(1),B1(1)
+      DIMENSION A1(IPI1(1)),B1(IQI1(1))
       DIMENSION IP(NMAX),IQ(NMAX),IPO(NMAX),IQO(NMAX)
       DIMENSION A2(MMAX,NMAX),B2(MMAX,NMAX)
       DIMENSION SMAIC2(NMAX),CXX2(NMAX)
@@ -381,7 +380,8 @@ cc  863 WRITE(6,864) I,B(I),STD(II)
 C     INVERSE OF AR(B) COMPUTATION
       IG=0
 cc	CALL INVERS(B,IQ,A,0,CC,IB,IG)
-      CALL INVERS(B,JQ,A,0,CC,IB,IG,IFG,LU)
+cx      CALL INVERS(B,JQ,A,0,CC,IB,IG,IFG,LU)
+      CALL INVERS(B,JQ,A,0,CC,IB,IST,IG,IFG,LU)
 cc	WRITE(6,4289) IB
 cx      IF (IFG.NE.0) WRITE(LU,4289) IB
 cc 4290 IF(IP.LE.0) GO TO 4291
@@ -396,16 +396,19 @@ cc 1001 FORMAT(/1H ,'AIC=N*LOG(CXX0)+2.0*(IQ+IP)=',D12.5)
 cc	WRITE(7,4) NEWN,IQ,IP,SAIC(NEWN)
 cc    4 FORMAT(/'CASE NO.',I2,1X,'AR',I2,1X,'MA',I2,2X,'AIC=',D12.5)
 cc	WRITE(7,1) IQ
-      IQ(NEWN)=JQ
 cc	IF(IQ.LE.0) GO TO 4292
 cc	WRITE(7,2) (B(I),I=1,IQ)
+      IF(JQ.LE.0) GO TO 4292
+      IQ(NEWN)=JQ
       DO 4200 I=1,JQ
 	 B2(I,NEWN)=B(I)
  4200 CONTINUE
 cc 4292 WRITE(7,1) IP
- 4292 IP(NEWN)=JP
+ 4292 CONTINUE
 cc	IF(IP.LE.0) GO TO 1000
 cc	WRITE(7,2) (A(I),I=1,IP)
+      IF(JP.LE.0) GO TO 1000
+      IP (NEWN)=JP
       DO 4201 I=1,JP
 	 A2(I,NEWN)=A(I)
  4201 CONTINUE
@@ -610,6 +613,7 @@ cc	DIMENSION CZY(1001),CZZ(1001)
 cc	DIMENSION AL(50,50)
       DIMENSION A2(IP*2),A2B(ICST),AIB(ICST),Y(LL*2+1)
       DIMENSION CXX(LL*2+1)
+      DIMENSION CXY(LL*2+1)
       DIMENSION CYX(LL*2+1)
       DIMENSION CUZ(LL*2+1)
       DIMENSION CYU(LL*2+1)
@@ -637,7 +641,8 @@ cc	IORIG=501
 C     ADJUSTMENT FOR FEASIBLE INITIAL
 C     INVERSE OF A(I) COMPUTATION
 cc   25 CALL INVERS(A,IP,B,0,AI,IA,IG)
-   25 CALL INVERS(A,IP,B,0,AI,IA,IG,IFG,LU)
+cx   25 CALL INVERS(A,IP,B,0,AI,IA,IG,IFG,LU)
+   25 CALL INVERS(A,IP,B,0,AI,IA,ICST,IG,IFG,LU)
       IF(ISIK.EQ.0) GO TO 26
       IF(ISWRO.NE.0) GO TO 1900
       IF(IDOS.NE.3) GO TO 1900
@@ -670,7 +675,8 @@ C
 C     AIB=(INVERSE OF A)*B
       IG=0
 cc	CALL INVERS(A,IP,B,IQ,AIB,IAIB,IG)
-      CALL INVERS(A,IP,B,IQ,AIB,IAIB,IG,IFG,LU)
+cx      CALL INVERS(A,IP,B,IQ,AIB,IAIB,IG,IFG,LU)
+      CALL INVERS(A,IP,B,IQ,AIB,IAIB,ICST,IG,IFG,LU)
 C     A2B=(INVERSE OF A*A)*B
 C     A2=A*A
       Y(IORIG)=CST1
@@ -694,7 +700,8 @@ cc	CALL SCONVL(Y,A2B,Y,IP,L2,M2)
   504 A2(I)=Y(IJ)
       IG=1
 cc	CALL INVERS(A2,I2P,B,IQ,A2B,IA2B,IG)
-      CALL INVERS(A2,I2P,B,IQ,A2B,IA2B,IG,IFG,LU)
+cx      CALL INVERS(A2,I2P,B,IQ,A2B,IA2B,IG,IFG,LU)
+      CALL INVERS(A2,I2P,B,IQ,A2B,IA2B,ICST,IG,IFG,LU)
       LXX=0
 cc	MXX=50
       MXX=MM
@@ -748,10 +755,16 @@ cc	CALL SCONVL(CYY,AIB,CYX,IAIB,LYX,MYX)
       CALL SCONVL(CYY,AIB,CYX,IAIB,LYX,MYX,LL)
 C
 cc	CALL TURN(CYX,CXY,LYX,MYX)
-      CALL TURN(CYX,CXX,LYX,MYX,LL)
+      DO 505 I=1,LL*2+1
+         CXY(I)=CXX(I)
+  505 CONTINUE
+      CALL TURN(CYX,CXY,LYX,MYX,LL)
 C     CXX=CXY*AIB'
-cc	CALL SCONVL(CXY,AIB,CXX,IAIB,LXX,MXX)
-      CALL SCONVL(CXX,AIB,CXX,IAIB,LXX,MXX,LL)
+cc      CALL SCONVL(CXY,AIB,CXX,IAIB,LXX,MXX)
+      CALL SCONVL(CXY,AIB,CXX,IAIB,LXX,MXX,LL)
+      DO 506 I=1,LL*2+1
+         CXX(I)=CXY(I)
+  506 CONTINUE
       CXX0=CXX(IORIG)
       IST=IORIG+LXX
       IEN=IORIG+MXX
@@ -866,7 +879,8 @@ cc	IORIG=501
       IB=IQ
 C     INVERSE OF A(I) COMPUTATION
 cc   24 CALL INVERS(A,IP,B,0,AI,IA,IG)
-   24 CALL INVERS(A,IP,B,0,AI,IA,IG,IFG,LU)
+cx   24 CALL INVERS(A,IP,B,0,AI,IA,IG,IFG,LU)
+   24 CALL INVERS(A,IP,B,0,AI,IA,ICST,IG,IFG,LU)
       IF(IG.NE.1) GO TO 1900
       GO TO 1000
  1900 IF(IA.NE.0) GO TO 1901
@@ -885,7 +899,8 @@ cc   24 CALL INVERS(A,IP,B,0,AI,IA,IG)
 C     AIB=(INVERSE OF A)*B
       IGAIB=0
 cc   25 CALL INVERS(A,IP,B,IQ,AIB,IAIB,IGAIB)
-   25 CALL INVERS(A,IP,B,IQ,AIB,IAIB,IGAIB,IFG,LU)
+cx   25 CALL INVERS(A,IP,B,IQ,AIB,IAIB,IGAIB,IFG,LU)
+   25 CALL INVERS(A,IP,B,IQ,AIB,IAIB,ICST,IGAIB,IFG,LU)
 C     A2B=(INVERSE OF A*A)*B
 C     A2=A*A
       Y(IORIG)=CST1
@@ -908,7 +923,8 @@ cc	CALL SCONVL(Y,A2B,Y,IP,L2,M2)
       IJ=IORIG-I
   504 A2(I)=Y(IJ)
 cc	CALL INVERS(A2,I2P,B,IQ,A2B,IA2B,IGA2B)
-      CALL INVERS(A2,I2P,B,IQ,A2B,IA2B,IGA2B,IFG,LU)
+cx      CALL INVERS(A2,I2P,B,IQ,A2B,IA2B,IGA2B,IFG,LU)
+      CALL INVERS(A2,I2P,B,IQ,A2B,IA2B,ICST,IGA2B,IFG,LU)
       LXX=0
       MXX=0
       LXY=0
@@ -1156,13 +1172,15 @@ cc	IORIG=501
       END
 C
 cc	SUBROUTINE INVERS(A,IP,B,IQ,X,IX,IG)
-      SUBROUTINE INVERS(A,IP,B,IQ,X,IX,IG,IFG,LU)
+cx      SUBROUTINE INVERS(A,IP,B,IQ,X,IX,IG,IFG,LU)
+      SUBROUTINE INVERS(A,IP,B,IQ,X,IX,ICST,IG,IFG,LU)
 C     X=(INVERSE OF B )*A
 C     W(I)+B(1)W(I-1)+...B(IQ)W(I-IQ)=X(I)+A(1)X(I-1)+...+A(IP)X(I-IP)
 C     INPUT W(0)=1, W(I)=0 FOR I. NE. 0
 C     OUTPUT X(I) (I=1,IX)
       IMPLICIT REAL*8(A-H,O-Z)
-      DIMENSION A(1),B(1),X(1)
+cx      DIMENSION A(1),B(1),X(1)
+      DIMENSION A(IP),B(IQ),X(ICST)
       CST0=0.0D-00
       IPQ=IP+IQ
       IF(IPQ.LE.0) GO TO 999
@@ -1174,7 +1192,8 @@ C     OUTPUT X(I) (I=1,IX)
       IF(IG.EQ.0) GO TO 13
       GCONST=0.01D-00
       IG=0
-   13 DO 10 I=1,190
+cx   13 DO 10 I=1,190
+   13 DO 10 I=1,ICST
       IX=I
       SUM=CST0
       IF(I.GT.IQ) GO TO 2
